@@ -10,12 +10,13 @@ namespace Sass {
     // https://developer.mozilla.org/en-US/docs/Web/CSS/Specificity
     // https://github.com/sass/sass/issues/1495#issuecomment-61189114
     extern const unsigned long Specificity_Star = 0;
-    extern const unsigned long Specificity_Universal = 1 << 0;
-    extern const unsigned long Specificity_Type = 1 << 8;
-    extern const unsigned long Specificity_Class = 1 << 16;
-    extern const unsigned long Specificity_Attr = 1 << 16;
-    extern const unsigned long Specificity_Pseudo = 1 << 16;
-    extern const unsigned long Specificity_ID = 1 << 24;
+    extern const unsigned long Specificity_Universal = 0;
+    extern const unsigned long Specificity_Element = 1;
+    extern const unsigned long Specificity_Base = 1000;
+    extern const unsigned long Specificity_Class = 1000;
+    extern const unsigned long Specificity_Attr = 1000;
+    extern const unsigned long Specificity_Pseudo = 1000;
+    extern const unsigned long Specificity_ID = 1000000;
 
     // sass keywords
     extern const char at_root_kwd[]       = "@at-root";
@@ -78,11 +79,11 @@ namespace Sass {
     extern const char supports_kwd[]     = "@supports";
     extern const char keyframes_kwd[]    = "keyframes";
     extern const char only_kwd[]         = "only";
-    extern const char rgb_kwd[]          = "rgb(";
+    extern const char rgb_fn_kwd[]       = "rgb(";
     extern const char url_kwd[]          = "url";
-    // extern const char url_prefix_kwd[]   = "url-prefix(";
+    // extern const char url_prefix_fn_kwd[] = "url-prefix(";
     extern const char important_kwd[]    = "important";
-    extern const char pseudo_not_kwd[]   = ":not(";
+    extern const char pseudo_not_fn_kwd[] = ":not(";
     extern const char even_kwd[]         = "even";
     extern const char odd_kwd[]          = "odd";
     extern const char progid_kwd[]       = "progid";
