@@ -79,10 +79,11 @@ namespace Sass {
     // but with specific ranges (copied from Ruby Sass)
     bool is_nonascii(const char& chr)
     {
+      unsigned int cmp = unsigned(chr);
       return (
-        (unsigned(chr) >= 128 && unsigned(chr) <= 15572911) ||
-        (unsigned(chr) >= 15630464 && unsigned(chr) <= 15712189) ||
-        (unsigned(chr) >= 4036001920)
+        (cmp >= 128 && cmp <= 15572911) ||
+        (cmp >= 15630464 && cmp <= 15712189) ||
+        (cmp >= 4036001920)
       );
     }
 
@@ -90,15 +91,17 @@ namespace Sass {
     // valid in a uri (copied from Ruby Sass)
     bool is_uri_character(const char& chr)
     {
-      return (unsigned(chr) > 41 && unsigned(chr) < 127) ||
-             unsigned(chr) == ':' || unsigned(chr) == '/';
+      unsigned int cmp = unsigned(chr);
+      return (cmp > 41 && cmp < 127) ||
+             cmp == ':' || cmp == '/';
     }
 
     // check if char is within a reduced ascii range
     // valid for escaping (copied from Ruby Sass)
     bool is_escapable_character(const char& chr)
     {
-      return unsigned(chr) > 31 && unsigned(chr) < 127;
+      unsigned int cmp = unsigned(chr);
+      return cmp > 31 && cmp < 127;
     }
 
     // Match word character (look ahead)
